instancelib.functions package
=============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   instancelib.functions.vectorize

Module contents
---------------

.. automodule:: instancelib.functions
   :members:
   :undoc-members:
   :show-inheritance:
